Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(599)

Unified Diff: ppapi/c/dev/ppb_video_decoder_dev.h

Issue 7021020: Clean up video frame sizes, types in Video Decode API (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: responses to CR Created 9 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « ppapi/c/dev/pp_video_dev.h ('k') | ppapi/c/dev/ppp_video_decoder_dev.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: ppapi/c/dev/ppb_video_decoder_dev.h
diff --git a/ppapi/c/dev/ppb_video_decoder_dev.h b/ppapi/c/dev/ppb_video_decoder_dev.h
index 5b8f0d48d7935f13979ed8feecd40b4eb7b8bc0a..881f098a09275a43d8dccc7f4098fca4dec0560f 100644
--- a/ppapi/c/dev/ppb_video_decoder_dev.h
+++ b/ppapi/c/dev/ppb_video_decoder_dev.h
@@ -9,8 +9,8 @@
#include "ppapi/c/pp_completion_callback.h"
#include "ppapi/c/pp_var.h"
-#define PPB_VIDEODECODER_DEV_INTERFACE_0_12 "PPB_VideoDecoder(Dev);0.12"
-#define PPB_VIDEODECODER_DEV_INTERFACE PPB_VIDEODECODER_DEV_INTERFACE_0_12
+#define PPB_VIDEODECODER_DEV_INTERFACE_0_13 "PPB_VideoDecoder(Dev);0.13"
+#define PPB_VIDEODECODER_DEV_INTERFACE PPB_VIDEODECODER_DEV_INTERFACE_0_13
// Video decoder interface.
//
@@ -20,7 +20,7 @@
// configure the decoder there.
// - Call Decode() to decode some video data.
// - Receive ProvidePictureBuffers callback
// - Supply the decoder with textures using AssignGLESBuffers.
// - Receive PictureReady callbacks
// - Hand the textures back to the decoder using ReusePictureBuffer.
// - To signal EOS to the decoder: call Flush() and wait for NotifyFlushDone
@@ -90,8 +90,9 @@ struct PPB_VideoDecoder_Dev {
// |no_of_buffers| how many buffers are behind picture buffer pointer.
// |buffers| contains the reference to the picture buffer that was
// allocated.
- void (*AssignGLESBuffers)(PP_Resource video_decoder, uint32_t no_of_buffers,
- const struct PP_GLESBuffer_Dev* buffers);
+ void (*AssignPictureBuffers)(
+ PP_Resource video_decoder, uint32_t no_of_buffers,
+ const struct PP_PictureBuffer_Dev* buffers);
// Tells the decoder to reuse the given picture buffer. Typical use of this
// function is to call from PictureReady callback to recycle picture buffer
« no previous file with comments | « ppapi/c/dev/pp_video_dev.h ('k') | ppapi/c/dev/ppp_video_decoder_dev.h » ('j') | no next file with comments »
@@ -20,7 +20,7 @@
// - Call Decode() to decode some video data.
// - Receive ProvidePictureBuffers callback
-// - Supply the decoder with textures using AssignGLESBuffers.
+// - Supply the decoder with textures using AssignPictureBuffers.
// - Receive PictureReady callbacks
// - Hand the textures back to the decoder using ReusePictureBuffer.

Powered by Google App Engine
This is Rietveld 408576698